@@ -1,6 +1,8 @@
 package Parse::CPAN::Packages::Package;
 use Moose;
 
+use PPI;
+
 has 'package'      => ( is => 'rw', isa => 'Str' );
 has 'version'      => ( is => 'rw', isa => 'Str' );
 has 'prefix'       => ( is => 'rw', isa => 'Str' );
@@ -24,6 +26,23 @@ sub file_content {
     return $content;
 }
 
+sub subs {
+    my ( $self ) = @_;
+
+    my $document = PPI::Document->new( \( $self->file_content ) );
+    my $subs = $document->find('PPI::Statement::Sub');
+
+    return map { $_->name } @{$subs};
+}
+
+sub has_matching_sub {
+    my ( $self, $sub_regex ) = @_;
+
+    my @matching_subs = grep { $_ =~ $sub_regex } $self->subs;
+
+    return @matching_subs;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -50,3 +69,12 @@ the files contained in the distribution it belongs to.
 =head2 file_content
 
 Tries to return the contents of the file returned by filename().
+
+=head2 subs
+
+Experimental function. Tries to return the names of all subs in the package.
+
+=head2 has_matching_sub( $regex )
+
+Experimental function. Tries to see if any sub name in the package matches the
+regex.
